@@ -203,20 +203,20 @@ class GalacticComponent(object):
         Uses jax autodiff to get the gradient of the density
 
         """
-        pass
+        raise NotImplementedError
 
     @staticmethod
     def from_gala_potential():
         """
         Initialize galactic density model from gala potential object
         """
-        pass
+        raise NotImplementedError
 
     def plot_countours():
         """
         plot contours of density in cylindrical coordinates
         """
-        pass 
+        raise NotImplementedError
 
 
 class Disk(GalacticComponent):
